const mongodb = require('mongodb');
const commonQueries = require('./common');

const { ObjectId } = mongodb;

function findSetupProdPrice(productPriceTypeId, productId, subproductId, setupId) {
  const query = {
    productPriceTypeId: ObjectId(productPriceTypeId),
    productId: ObjectId(productId),
    setupId: ObjectId(setupId),
  };
  if (subproductId) { query.subproductId = ObjectId(subproductId); }
  return query;
}

function findCurrentGroupSetup(setupId, groupId) {
  return {
    setupId: ObjectId(setupId),
    groupId: ObjectId(groupId),
    active: true,
  };
}

function findCurrentThirdSetup(setupId, thirdPartyId) {
  return {
    setupId: ObjectId(setupId),
    thirdPartyId: ObjectId(thirdPartyId),
    active: true,
  };
}

function findGroupSetup(groupId) {
  return {
    groupId: ObjectId(groupId),
    active: true,
  };
}

function findThirdSetup(thirdPartyId) {
  return {
    thirdPartyId: ObjectId(thirdPartyId),
    active: true,
  };
}

function addScale(scale) {
  return {
    $addToSet: {
      scales: scale,
    },
  };
}

function deleteScale(minValue) {
  return {
    $pull: {
      scales: { minValue },
    },
  };
}

function findAuditSetupProdPrice(productPriceTypeId, productId, subproductId, setupId) {
  return { productPriceTypeId, productId, subproductId, setupId, priceEndDate: null };
}

function findBySetup(setupId) {
  return { setupId: ObjectId(setupId) };
}

module.exports = {
  ...commonQueries,
  // Stores
  findSetupProdPrice,
  findGroupSetup,
  findAuditSetupProdPrice,
  findCurrentGroupSetup,
  findThirdSetup,
  findCurrentThirdSetup,
  addScale,
  deleteScale,
  findBySetup,
};
